@@ -19,7 +19,7 @@ def create_app(config_name):
     config = config_dict[config_name]
     app = Flask(__name__)
     app.config.from_object(config)
-    configDict[config_name].init_app(app)
+    config.init_app(app)
 
     logging.basicConfig(level=logging.ERROR)
 
